using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Text;
using System.Windows.Forms;
using Infragistics.Excel;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;

namespace TestBed
{
    public partial class Form4 : Form
    {
        public Form4()
        {
            InitializeComponent();

            this.Load += new EventHandler(Form4_Load);

            ultraGrid1.InitializeRow += new Infragistics.Win.UltraWinGrid.InitializeRowEventHandler(ultraGrid1_InitializeRow);
        }

        void ultraGrid1_InitializeRow(object sender, Infragistics.Win.UltraWinGrid.InitializeRowEventArgs e)
        {
            DataR.MaxValue = 5;

            if (e.ReInitialize)
                return;

            foreach (UltraGridCell gridCell in e.Row.Cells)
            {
                if (gridCell.Column.DataType == typeof(string))
                    continue;

                ColorCell(gridCell);
            }
        }

        private void ColorCell(UltraGridCell gridCell)
        {
            int colorInt = DataR.RandomInt;

            switch (colorInt)
            {
                case 0:
                    gridCell.Appearance.BackColor = System.Drawing.Color.YellowGreen;
                    break;
                case 1:
                    gridCell.Appearance.BackColor = System.Drawing.Color.Lime;
                    break;
                case 2:
                    gridCell.Appearance.BackColor = System.Drawing.Color.PaleTurquoise;
                    break;
                case 3:
                    gridCell.Appearance.ForeColor = System.Drawing.Color.White;
                    gridCell.Appearance.BackColor = System.Drawing.Color.Blue;
                    break;
                case 4:
                    gridCell.Appearance.BackColor = System.Drawing.Color.DarkOrange;
                    break;
                
            }

            switch (DataR.RandomInt)
            {
                    case 0:
                    gridCell.Appearance.BackColor2 = gridCell.Appearance.BackColor;
                    gridCell.Appearance.BackColor = Color.Linen;
                    gridCell.Appearance.ForeColor = Color.Red;
                    gridCell.Appearance.BackHatchStyle = BackHatchStyle.DiagonalBrick;
                    break;
                case 1:
                    gridCell.Appearance.BackColor2 = Color.Red;
                    gridCell.Appearance.BackGradientStyle = GradientStyle.GlassLeft50;
                    break;
                case 2:
                    gridCell.Appearance.BackColor2 = Color.Green;
                    gridCell.Appearance.BackGradientStyle = GradientStyle.GlassLeft50;
                    break;
                case 3:
                    gridCell.Appearance.BackColor2 = gridCell.Appearance.BackColor;
                    gridCell.Appearance.BackColor = Color.Black;
                    gridCell.Appearance.BackHatchStyle = BackHatchStyle.Percent60;
                    break;
            }
        }

        private DataRepository _dataR;
        private DataRepository DataR
        {
            get
            {
                if (null == _dataR)
                {
                    _dataR = new DataRepository();
                }

                return _dataR;
            }
        }

        void Form4_Load(object sender, EventArgs e)
        {
            LoadData();
        }

        public void LoadData()
        {
            ultraGrid1.DataSource = DataR.GetData();
            ultraGrid1.DataBind();
        }

        public void Export(Workbook workbook, string reportName)
        {
            LoadData();

            InitWorkbook(workbook, reportName);

            ultraGridExcelExporter1.Export(ultraGrid1, workbook);

            workbook.Save(FilePath);
        }


        public void Export(string reportName)
        {
            Workbook workbook = GetWorkBook(FilePath);
            Export(workbook, reportName);
        }

        private void reportBtn_Click(object sender, EventArgs e)
        {
            int numberOfReports = 12;

            Cursor = Cursors.WaitCursor;

            try
            {
                for (int report = 0; report < numberOfReports; report++)
                {
                    string reportName = "Report " + report;
                    
                    Export(reportName);
                }

            }
                catch(Exception ex)
                {
                    MessageBox.Show("Error during export" + ex.Message);
                }
            finally
            {
                Cursor = Cursors.Default;
            }
            
        }

        private void reportBtn2_Click(object sender, EventArgs e)
        {
            int numberOfReports = 12;

            Workbook workbook = GetWorkBook(FilePath);

            Cursor = Cursors.WaitCursor;

            try
            {
                
                for (int report = 0; report < numberOfReports; report++)
                {
                    string reportName = "Report " + report;

                    Export(workbook, reportName); 
                }

            }
            catch (Exception ex)
            {
                MessageBox.Show("Error during export" + ex.Message);
            }
            finally
            {
                workbook = null;
                Cursor = Cursors.Default;
            }

        }

        public static Workbook GetWorkBook(string filePath)
        {
            return !File.Exists(filePath) ? new Workbook() : Workbook.Load(filePath);
        }

        private string ReportName
        {
            get
            {
                return "SampleReport.xls";
            }
        }

        private string FilePath
        {
            get
            {
                string deskTopPath = Environment.GetFolderPath(Environment.SpecialFolder.Desktop);
                string filePath = deskTopPath + Path.DirectorySeparatorChar + ReportName;
                return filePath;
            }
        }

        /// <summary>
        /// Return the current active workbook, deletes and adds new worksheet as needed
        /// </summary>
        /// <param name="workSheetName"></param>
        /// <param name="workbook"></param>
        /// <returns></returns>
        private Workbook InitWorkbook(Workbook workbook, string workSheetName)
        {

            if (!string.IsNullOrEmpty(workSheetName))
            {
                if (workbook.Worksheets.Exists(workSheetName))
                {
                    Worksheet worksheet = workbook.Worksheets[workSheetName];

                    if (null != worksheet)
                    {
                        workbook.Worksheets.Remove(worksheet);
                        worksheet = workbook.Worksheets.Add(workSheetName);
                        //worksheet.DataTables.Clear();
                    }
                }
                else
                {
                    workbook.Worksheets.Add(workSheetName);
                }

                workbook.WindowOptions.SelectedWorksheet = workbook.Worksheets[workSheetName];
            }

            return workbook;
        }
        
    }
}